@@ -1533,6 +1533,7 @@ int actor_get(const char *actor, xs_dict **data)
     else
         d = xs_free(d);
 
+#ifdef STALE_ACTORS
     xs *fn = _object_fn(actor);
     double max_time;
 
@@ -1547,6 +1548,7 @@ int actor_get(const char *actor, xs_dict **data)
 
         status = 205; /* "205: Reset Content" "110: Response Is Stale" */
     }
+#endif /* STALE_ACTORS */
 
     return status;
 }
@@ -2045,13 +2047,33 @@ void notify_add(snac *snac, const char *type, const char *utype,
         xs_json_dump(noti, 4, f);
         fclose(f);
     }
+
+    /* add it to the index if it already exists */
+    xs *idx = xs_fmt("%s/notify.idx", snac->basedir);
+
+    if (mtime(idx) != 0.0) {
+        pthread_mutex_lock(&data_mutex);
+
+        if ((f = fopen(idx, "a")) != NULL) {
+            fprintf(f, "%-32s\n", ntid);
+            fclose(f);
+        }
+
+        pthread_mutex_unlock(&data_mutex);
+    }
 }
 
 
 xs_dict *notify_get(snac *snac, const char *id)
 /* gets a notification */
 {
-    xs *fn = xs_fmt("%s/notify/%s.json", snac->basedir, id);
+    /* base file */
+    xs *fn = xs_fmt("%s/notify/%s", snac->basedir, id);
+
+    /* strip spaces and add extension */
+    fn = xs_strip_i(fn);
+    fn = xs_str_cat(fn, ".json");
+
     FILE *f;
     xs_dict *out = NULL;
 
@@ -2064,32 +2086,62 @@ xs_dict *notify_get(snac *snac, const char *id)
 }
 
 
-xs_list *notify_list(snac *snac, int new_only)
-/* returns a list of notification ids, optionally only the new ones */
+xs_list *notify_list(snac *snac, int skip, int show)
+/* returns a list of notification ids */
 {
-    xs *t = NULL;
+    xs *idx = xs_fmt("%s/notify.idx", snac->basedir);
 
-    /* if only new ones are requested, get the last time */
-    if (new_only)
-        t = notify_check_time(snac, 0);
+    if (mtime(idx) == 0.0) {
+        /* create the index from scratch */
+        FILE *f;
 
-    xs *spec     = xs_fmt("%s/notify/" "*.json", snac->basedir);
-    xs *lst      = xs_glob(spec, 1, 1);
-    xs_list *out = xs_list_new();
-    xs_list *p   = lst;
+        pthread_mutex_lock(&data_mutex);
+
+        if ((f = fopen(idx, "w")) != NULL) {
+            xs *spec = xs_fmt("%s/notify/" "*.json", snac->basedir);
+            xs *lst  = xs_glob(spec, 1, 0);
+            xs_list *p = lst;
+            char *v;
+
+            while (xs_list_iter(&p, &v)) {
+                char *p = strrchr(v, '.');
+                if (p) {
+                    *p = '\0';
+                    fprintf(f, "%-32s\n", v);
+                }
+            }
+
+            fclose(f);
+        }
+
+        pthread_mutex_unlock(&data_mutex);
+    }
+
+    return index_list_desc(idx, skip, show);
+}
+
+
+int notify_new_num(snac *snac)
+/* counts the number of new notifications */
+{
+    xs *t = notify_check_time(snac, 0);
+    xs *lst = notify_list(snac, 0, XS_ALL);
+    int cnt = 0;
+
+    xs_list *p = lst;
     xs_str *v;
 
     while (xs_list_iter(&p, &v)) {
-        xs *id = xs_replace(v, ".json", "");
+        xs *id = xs_strip_i(xs_dup(v));
 
-        /* old? */
-        if (t != NULL && strcmp(id, t) < 0)
-            continue;
+        /* old? count no more */
+        if (strcmp(id, t) < 0)
+            break;
 
-        out = xs_list_append(out, id);
+        cnt++;
     }
 
-    return out;
+    return cnt;
 }
 
 
@@ -2103,6 +2155,14 @@ void notify_clear(snac *snac)
 
     while (xs_list_iter(&p, &v))
         unlink(v);
+
+    xs *idx = xs_fmt("%s/notify.idx", snac->basedir);
+
+    if (mtime(idx) != 0.0) {
+        pthread_mutex_lock(&data_mutex);
+        truncate(idx, 0);
+        pthread_mutex_unlock(&data_mutex);
+    }
 }
 
 
