@@ -1500,24 +1500,9 @@ int mastoapi_get_handler(const xs_dict *req, const char *q_path,
             if (strcmp(type, "Note") != 0 && strcmp(type, "Question") != 0)
                 continue;
 
-            /* discard private users */
-            {
-                const char *atto = get_atto(msg);
-                xs *l = xs_split(atto, "/");
-                const char *uid = xs_list_get(l, -1);
-                snac p_user;
-                int skip = 1;
-
-                if (uid && user_open(&p_user, uid)) {
-                    if (xs_type(xs_dict_get(p_user.config, "private")) != XSTYPE_TRUE)
-                        skip = 0;
-
-                    user_free(&p_user);
-                }
-
-                if (skip)
-                    continue;
-            }
+            /* discard messages from private users */
+            if (is_msg_from_private_user(msg))
+                continue;
 
             /* convert the Note into a Mastodon status */
             xs *st = mastoapi_status(user, msg);
@@ -1533,6 +1518,55 @@ int mastoapi_get_handler(const xs_dict *req, const char *q_path,
         status = 200;
     }
     else
+    if (xs_startswith(cmd, "/v1/timelines/tag/")) { /** **/
+        const char *limit_s = xs_dict_get(args, "limit");
+        int limit = 0;
+        int cnt   = 0;
+
+        if (!xs_is_null(limit_s))
+            limit = atoi(limit_s);
+
+        if (limit == 0)
+            limit = 20;
+
+        /* get the tag */
+        xs *l = xs_split(cmd, "/");
+        char *tag = xs_list_get(l, -1);
+
+        xs *timeline = tag_search(tag, 0, limit);
+        xs *out      = xs_list_new();
+        xs_list *p   = timeline;
+        xs_str *md5;
+
+        while (xs_list_iter(&p, &md5) && cnt < limit) {
+            xs *msg = NULL;
+
+            /* get the entry */
+            if (!valid_status(object_get_by_md5(md5, &msg)))
+                continue;
+
+            /* skip non-public messages */
+            if (!is_msg_public(msg))
+                continue;
+
+            /* discard messages from private users */
+            if (is_msg_from_private_user(msg))
+                continue;
+
+            /* convert the Note into a Mastodon status */
+            xs *st = mastoapi_status(NULL, msg);
+
+            if (st != NULL) {
+                out = xs_list_append(out, st);
+                cnt++;
+            }
+        }
+
+        *body  = xs_json_dumps(out, 4);
+        *ctype = "application/json";
+        status = 200;
+    }
+    else
     if (strcmp(cmd, "/v1/conversations") == 0) { /** **/
         /* TBD */
         *body  = xs_dup("[]");
@@ -1542,7 +1576,7 @@ int mastoapi_get_handler(const xs_dict *req, const char *q_path,
     else
     if (strcmp(cmd, "/v1/notifications") == 0) { /** **/
         if (logged_in) {
-            xs *l      = notify_list(&snac1, 0);
+            xs *l      = notify_list(&snac1, 0, 64);
             xs *out    = xs_list_new();
             xs_list *p = l;
             xs_dict *v;
