@@ -1,7 +1,7 @@
 /* snac - A simple, minimalistic ActivityPub instance */
 /* copyright (c) 2022 - 2024 grunfink et al. / MIT license */
 
-#define VERSION "2.46"
+#define VERSION "2.47"
 
 #define USER_AGENT "snac/" VERSION
 
@@ -187,7 +187,8 @@ xs_str *notify_check_time(snac *snac, int reset);
 void notify_add(snac *snac, const char *type, const char *utype,
                 const char *actor, const char *objid);
 xs_dict *notify_get(snac *snac, const char *id);
-xs_list *notify_list(snac *snac, int new_only);
+int notify_new_num(snac *snac);
+xs_list *notify_list(snac *snac, int skip, int show);
 void notify_clear(snac *snac);
 
 void inbox_add(const char *inbox);
@@ -276,6 +277,7 @@ xs_str *get_actor_inbox(const char *actor);
 int send_to_actor(snac *snac, const char *actor, const xs_dict *msg,
                   xs_val **payload, int *p_size, int timeout);
 int is_msg_public(const xs_dict *msg);
+int is_msg_from_private_user(const xs_dict *msg);
 int is_msg_for_me(snac *snac, const xs_dict *msg);
 
 int process_user_queue(snac *snac);
